@@ -8,7 +8,7 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
         stop("'x' must be a square array.")
     ifelse(missing(sep) == TRUE, sep <- ", ", NA)
     ifelse(isTRUE(is.null(dimnames(x)[1]) == TRUE | is.null(dimnames(x)[1][[1]]) == 
-        TRUE) == TRUE, LBS <- 1:nrow(x), LBS <- dimnames(x)[[1]])
+        TRUE) == TRUE, LBS <- seq_len(nrow(x)), LBS <- dimnames(x)[[1]])
     lbs <- seq(LBS)
     xd <- dichot(x, c = 1L, diag.incl = TRUE)
     ifelse(isTRUE(dim(xd)[3] == 1) == TRUE, xd <- xd[, , 1], 
@@ -18,11 +18,11 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
         r <- dim(x)[3]
         if (isTRUE(is.null(dimnames(x)[[3]]) == TRUE) | isTRUE(any(duplicated(dimnames(x)[[3]]))) == 
             TRUE) {
-            dimnames(x)[[3]] <- 1:dim(x)[3]
+            dimnames(x)[[3]] <- seq_len(dim(x)[3])
         }
         mlt <- list()
-        for (i in 1:dim(x)[3]) {
-            mlt[[i]] <- transf(xd[, , i], type = "tolist", labels = lbs, 
+        for (i in seq_len(dim(x)[3])) {
+            mlt[[i]] <- trnf(xd[, , i], tolist = TRUE, lbs = lbs, 
                 sep = sep, lb2lb = lb2lb)
         }
         rm(i)
@@ -31,32 +31,31 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
     else {
         TRD <- FALSE
         r <- 1
-        m <- transf(xd, type = "tolist", labels = lbs, sep = sep, 
-            lb2lb = lb2lb)
+        m <- trnf(xd, tolist = TRUE, lbs = lbs, sep = sep, lb2lb = lb2lb)
     }
     if (smpl) {
         if (isTRUE(TRD == TRUE) == TRUE) {
             tmp <- list()
             tt <- vector()
             if (isTRUE(is.null(dimnames(x)[[3]])) == FALSE) {
-                for (i in 1:length(dimnames(x)[[3]])) tmp[i] <- dimnames(x)[[3]][i]
+                for (i in seq_len(length(dimnames(x)[[3]]))) tmp[i] <- dimnames(x)[[3]][i]
                 rm(i)
-                for (i in 1:length(tmp)) tt[i] <- (strsplit(tmp[[i]], 
+                for (i in seq_len(length(tmp))) tt[i] <- (strsplit(tmp[[i]], 
                   "")[[1]][1])
                 rm(i)
             }
             else {
-                for (i in 1:dim(x)[3]) tt[i] <- tmp[i] <- i
+                for (i in seq_len(dim(x)[3])) tt[i] <- tmp[i] <- i
                 rm(i)
             }
-            for (k in 1:r) {
+            for (k in seq_len(r)) {
                 allr <- paste("all", tt[k], sep = "_")
-                assign(allr, transf(xd[, , k], type = "tolist", 
-                  labels = lbs, sep = sep, lb2lb = lb2lb))
-                tmp <- transf(xd[, , k], type = "tolist", labels = lbs, 
+                assign(allr, trnf(xd[, , k], tolist = TRUE, lbs = lbs, 
+                  sep = sep, lb2lb = lb2lb))
+                tmp <- trnf(xd[, , k], tolist = TRUE, lbs = lbs, 
                   sep = sep, lb2lb = lb2lb)
                 tDF <- data.frame(matrix(ncol = 2L, nrow = 0L))
-                for (i in 1:length(tmp)) {
+                for (i in seq_len(length(tmp))) {
                   tDF[i, 1] <- strsplit(tmp[i], sep)[[1]][1]
                   tDF[i, 2] <- strsplit(tmp[i], sep)[[1]][2]
                 }
@@ -65,7 +64,7 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
                 oud <- list()
                 ind <- list()
                 ald <- list()
-                for (i in 1:length(lbs)) {
+                for (i in seq_len(length(lbs))) {
                   oud[[i]] <- as.numeric(tDF[which(tDF[, 1] == 
                     as.numeric(lbs[i])), 2])
                   ind[[i]] <- as.numeric(tDF[which(tDF[, 2] == 
@@ -90,8 +89,8 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
     }
     bd <- bnd(x, xd, lbs, TRD, r, m, mlt, sep)
     As <- vector()
-    for (i in 1:length(bd$asym)) {
-        for (j in 1:length(bd$asym[[i]])) {
+    for (i in seq_len(length(bd$asym))) {
+        for (j in seq_len(length(bd$asym[[i]]))) {
             if (isTRUE(length(bd$asym[[i]]) != 0L) == TRUE) {
                 if (isTRUE(is.na(dim(x)[3])) == FALSE) {
                   As <- append(As, paste(lbs[i], bd$asym[[i]][j], 
@@ -109,10 +108,10 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
     rm(i)
     if (isTRUE(TRD == TRUE) == TRUE) {
         AS <- list()
-        for (k in 1:r) {
+        for (k in seq_len(r)) {
             tmp <- vector()
-            for (i in which(As %in% transf(xd[, , k], labels = lbs, 
-                sep = sep, lb2lb = lb2lb))) {
+            for (i in which(As %in% trnf(xd[, , k], tolist = TRUE, 
+                lbs = lbs, sep = sep, lb2lb = lb2lb))) {
                 tmp <- append(tmp, As[i])
             }
             rm(i)
@@ -124,8 +123,8 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
         AS <- as.character(As)
     }
     Rp <- vector()
-    for (i in 1:length(bd$recp)) {
-        for (j in 1:length(bd$recp[[i]])) {
+    for (i in seq_len(length(bd$recp))) {
+        for (j in seq_len(length(bd$recp[[i]]))) {
             if (isTRUE(length(bd$recp[[i]]) != 0L) == TRUE) {
                 Rp <- append(Rp, paste(lbs[i], bd$recp[[i]][j], 
                   sep = sep))
@@ -136,10 +135,10 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
     rm(i)
     if (isTRUE(TRD == TRUE) == TRUE) {
         RP <- list()
-        for (k in 1:r) {
+        for (k in seq_len(r)) {
             tmp <- vector()
-            for (i in which(Rp %in% transf(xd[, , k], labels = lbs, 
-                sep = sep, lb2lb = lb2lb))) {
+            for (i in which(Rp %in% trnf(xd[, , k], tolist = TRUE, 
+                lbs = lbs, sep = sep, lb2lb = lb2lb))) {
                 tmp <- append(tmp, Rp[i])
             }
             rm(i)
@@ -152,8 +151,8 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
     }
     Xc <- vector()
     if (isTRUE(TRD == TRUE) == TRUE) {
-        for (i in 1:length(bd$xchg)) {
-            for (j in 1:length(bd$xchg[[i]])) {
+        for (i in seq_len(length(bd$xchg))) {
+            for (j in seq_len(length(bd$xchg[[i]]))) {
                 if (isTRUE(length(bd$xchg[[i]]) != 0L) == TRUE) {
                   if (isTRUE(lbs[i] < bd$xchg[[i]][j]) == TRUE) 
                     Xc <- append(Xc, paste(lbs[i], bd$xchg[[i]][j], 
@@ -165,16 +164,16 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
         rm(i)
         XC <- list()
         XCt <- list()
-        for (k in 1:r) {
+        for (k in seq_len(r)) {
             tmp <- vector()
             tmpt <- vector()
-            for (i in which(Xc %in% transf(xd[, , k], labels = lbs, 
-                sep = sep, lb2lb = lb2lb))) {
+            for (i in which(Xc %in% trnf(xd[, , k], tolist = TRUE, 
+                lbs = lbs, sep = sep, lb2lb = lb2lb))) {
                 tmp <- append(tmp, Xc[i])
             }
             rm(i)
-            for (i in which(Xc %in% transf(t(xd[, , k]), labels = lbs, 
-                sep = sep, lb2lb = lb2lb))) {
+            for (i in which(Xc %in% trnf(t(xd[, , k]), tolist = TRUE, 
+                lbs = lbs, sep = sep, lb2lb = lb2lb))) {
                 tmpt <- append(tmpt, paste(strsplit(Xc[i], sep)[[1]][2], 
                   strsplit(Xc[i], sep)[[1]][1], sep = sep))
             }
@@ -184,7 +183,7 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
         }
         rm(k)
         XCH <- list()
-        for (i in 1:length(XC)) {
+        for (i in seq_len(length(XC))) {
             XCH[[i]] <- as.character(c(XC[[i]], XCt[[i]]))
         }
         rm(i)
@@ -194,8 +193,8 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
     }
     Et <- vector()
     if (isTRUE(TRD == TRUE) == TRUE) {
-        for (i in 1:length(bd$Eout)) {
-            for (j in 1:length(bd$Eout[[i]])) {
+        for (i in seq_len(length(bd$Eout))) {
+            for (j in seq_len(length(bd$Eout[[i]]))) {
                 if (isTRUE(length(bd$Eout[[i]]) != 0L) == TRUE) {
                   Et <- append(Et, paste(lbs[i], bd$Eout[[i]][j], 
                     sep = sep))
@@ -205,10 +204,10 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
         }
         rm(i)
         ENT <- list()
-        for (k in 1:r) {
+        for (k in seq_len(r)) {
             tmp <- vector()
-            for (i in which(Et %in% transf(xd[, , k], labels = lbs, 
-                sep = sep, lb2lb = lb2lb))) {
+            for (i in which(Et %in% trnf(xd[, , k], tolist = TRUE, 
+                lbs = lbs, sep = sep, lb2lb = lb2lb))) {
                 tmp <- append(tmp, Et[i])
             }
             rm(i)
@@ -221,8 +220,8 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
     }
     Mx <- vector()
     if (isTRUE(TRD == TRUE) == TRUE) {
-        for (i in 1:length(bd$mixe)) {
-            for (j in 1:length(bd$mixe[[i]])) {
+        for (i in seq_len(length(bd$mixe))) {
+            for (j in seq_len(length(bd$mixe[[i]]))) {
                 if (isTRUE(length(bd$mixe[[i]]) != 0L) == TRUE) {
                   if (isTRUE(lbs[i] < bd$mixe[[i]][j]) == TRUE) 
                     Mx <- append(Mx, paste(lbs[i], bd$mixe[[i]][j], 
@@ -234,16 +233,16 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
         rm(i)
         MX <- list()
         MXt <- list()
-        for (k in 1:r) {
+        for (k in seq_len(r)) {
             tmp <- vector()
             tmpt <- vector()
-            for (i in which(Mx %in% transf(xd[, , k], labels = lbs, 
-                sep = sep, lb2lb = lb2lb))) {
+            for (i in which(Mx %in% trnf(xd[, , k], tolist = TRUE, 
+                lbs = lbs, sep = sep, lb2lb = lb2lb))) {
                 tmp <- append(tmp, Mx[i])
             }
             rm(i)
-            for (i in which(Mx %in% transf(t(xd[, , k]), labels = lbs, 
-                sep = sep, lb2lb = lb2lb))) {
+            for (i in which(Mx %in% trnf(t(xd[, , k]), tolist = TRUE, 
+                lbs = lbs, sep = sep, lb2lb = lb2lb))) {
                 tmpt <- append(tmpt, paste(strsplit(Mx[i], sep)[[1]][2], 
                   strsplit(Mx[i], sep)[[1]][1], sep = sep))
             }
@@ -253,7 +252,7 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
         }
         rm(k)
         MIX <- list()
-        for (i in 1:length(MX)) {
+        for (i in seq_len(length(MX))) {
             MIX[[i]] <- as.character(c(MX[[i]], MXt[[i]]))
         }
         rm(i)
@@ -263,8 +262,8 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
     }
     Fl <- vector()
     if (isTRUE(TRD == TRUE) == TRUE) {
-        for (i in 1:length(bd$full)) {
-            for (j in 1:length(bd$full[[i]])) {
+        for (i in seq_len(length(bd$full))) {
+            for (j in seq_len(length(bd$full[[i]]))) {
                 if (isTRUE(length(bd$full[[i]]) != 0L) == TRUE) {
                   if (isTRUE(lbs[i] < bd$full[[i]][j]) == TRUE) 
                     Fl <- append(Fl, paste(lbs[i], bd$full[[i]][j], 
@@ -276,16 +275,16 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
         rm(i)
         FL <- list()
         FLt <- list()
-        for (k in 1:r) {
+        for (k in seq_len(r)) {
             tmp <- vector()
             tmpt <- vector()
-            for (i in which(Fl %in% transf(xd[, , k], labels = lbs, 
-                sep = sep, lb2lb = lb2lb))) {
+            for (i in which(Fl %in% trnf(xd[, , k], tolist = TRUE, 
+                lbs = lbs, sep = sep, lb2lb = lb2lb))) {
                 tmp <- append(tmp, Fl[i])
             }
             rm(i)
-            for (i in which(Fl %in% transf(t(xd[, , k]), labels = lbs, 
-                sep = sep, lb2lb = lb2lb))) {
+            for (i in which(Fl %in% trnf(t(xd[, , k]), tolist = TRUE, 
+                lbs = lbs, sep = sep, lb2lb = lb2lb))) {
                 tmpt <- append(tmpt, paste(strsplit(Fl[i], sep)[[1]][2], 
                   strsplit(Fl[i], sep)[[1]][1], sep = sep))
             }
@@ -295,7 +294,7 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
         }
         rm(k)
         FUL <- list()
-        for (i in 1:length(FL)) {
+        for (i in seq_len(length(FL))) {
             FUL[[i]] <- as.character(c(FL[[i]], FLt[[i]]))
         }
         rm(i)
@@ -306,8 +305,8 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
     if (lb2lb) {
         if (isTRUE(is.null(dimnames(x)[[1]]) == TRUE) == FALSE) {
             if (length(AS) > 0L) {
-                for (k in 1:length(AS)) {
-                  for (i in 1:length(AS[[k]])) {
+                for (k in seq_len(length(AS))) {
+                  for (i in seq_len(length(AS[[k]]))) {
                     if (length(AS[[k]]) > 0L) {
                       AS[[k]][i] <- paste(dimnames(x)[[1]][as.numeric(strsplit(AS[[k]][i], 
                         sep)[[1]][1])], dimnames(x)[[1]][as.numeric(strsplit(AS[[k]][i], 
@@ -319,8 +318,8 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
                 rm(k)
             }
             if (length(RP) > 0L) {
-                for (k in 1:length(RP)) {
-                  for (i in 1:length(RP[[k]])) {
+                for (k in seq_len(length(RP))) {
+                  for (i in seq_len(length(RP[[k]]))) {
                     if (length(RP[[k]]) > 0L) {
                       RP[[k]][i] <- paste(dimnames(x)[[1]][as.numeric(strsplit(RP[[k]][i], 
                         sep)[[1]][1])], dimnames(x)[[1]][as.numeric(strsplit(RP[[k]][i], 
@@ -333,8 +332,8 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
             }
             if (isTRUE(is.na(dim(x)[3])) == FALSE) {
                 if (length(XCH) > 0L) {
-                  for (k in 1:length(XCH)) {
-                    for (i in 1:length(XCH[[k]])) {
+                  for (k in seq_len(length(XCH))) {
+                    for (i in seq_len(length(XCH[[k]]))) {
                       if (length(XCH[[k]]) > 0L) {
                         XCH[[k]][i] <- paste(dimnames(x)[[1]][as.numeric(strsplit(XCH[[k]][i], 
                           sep)[[1]][1])], dimnames(x)[[1]][as.numeric(strsplit(XCH[[k]][i], 
@@ -346,8 +345,8 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
                   rm(k)
                 }
                 if (length(ENT) > 0L) {
-                  for (k in 1:length(ENT)) {
-                    for (i in 1:length(ENT[[k]])) {
+                  for (k in seq_len(length(ENT))) {
+                    for (i in seq_len(length(ENT[[k]]))) {
                       if (length(ENT[[k]]) > 0L) {
                         ENT[[k]][i] <- paste(dimnames(x)[[1]][as.numeric(strsplit(ENT[[k]][i], 
                           sep)[[1]][1])], dimnames(x)[[1]][as.numeric(strsplit(ENT[[k]][i], 
@@ -359,8 +358,8 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
                   rm(k)
                 }
                 if (length(MIX) > 0L) {
-                  for (k in 1:length(MIX)) {
-                    for (i in 1:length(MIX[[k]])) {
+                  for (k in seq_len(length(MIX))) {
+                    for (i in seq_len(length(MIX[[k]]))) {
                       if (length(MIX[[k]]) > 0L) {
                         MIX[[k]][i] <- paste(dimnames(x)[[1]][as.numeric(strsplit(MIX[[k]][i], 
                           sep)[[1]][1])], dimnames(x)[[1]][as.numeric(strsplit(MIX[[k]][i], 
@@ -372,8 +371,8 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
                   rm(k)
                 }
                 if (length(FUL) > 0L) {
-                  for (k in 1:length(FUL)) {
-                    for (i in 1:length(FUL[[k]])) {
+                  for (k in seq_len(length(FUL))) {
+                    for (i in seq_len(length(FUL[[k]]))) {
                       if (length(FUL[[k]]) > 0L) {
                         FUL[[k]][i] <- paste(dimnames(x)[[1]][as.numeric(strsplit(FUL[[k]][i], 
                           sep)[[1]][1])], dimnames(x)[[1]][as.numeric(strsplit(FUL[[k]][i], 
@@ -391,10 +390,10 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
         if (isTRUE(TRD == TRUE) == TRUE) {
             LOP <- list()
             length(LOP) <- dim(x)[3]
-            for (i in 1:dim(x)[3]) {
+            for (i in seq_len(dim(x)[3])) {
                 lp <- which(diag(xd[, , i]) != 0L)
                 if (isTRUE(length(lp) > 0L) == TRUE) {
-                  for (j in 1:length(lp)) {
+                  for (j in seq_len(length(lp))) {
                     if (lb2lb) {
                       if (isTRUE(is.null(dimnames(x)[[1]])) == 
                         FALSE) {
@@ -424,7 +423,7 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
         else {
             LOP <- vector()
             lp <- which(diag(xd) != 0L)
-            for (j in 1:length(lp)) {
+            for (j in seq_len(length(lp))) {
                 LOP <- append(LOP, paste(LBS[lp][j], LBS[lp][j], 
                   sep = sep))
             }
