@@ -1,5 +1,5 @@
 perm <-
-function (x, clu, rev = FALSE) 
+function (x, clu, rev = FALSE, lbs) 
 {
     if (isTRUE(is.array(x) == TRUE) == FALSE) 
         stop("'x' must be an array object.")
@@ -11,7 +11,7 @@ function (x, clu, rev = FALSE)
     }
     else if (is.character(clu) == TRUE) {
         tmp <- clu
-        for (i in 1:nlevels(factor(clu))) {
+        for (i in seq_len(nlevels(factor(clu)))) {
             clu[which(levels(factor(tmp))[i] == clu)] <- i
         }
         rm(i)
@@ -29,7 +29,7 @@ function (x, clu, rev = FALSE)
     }
     rm(i)
     if (isTRUE(any(is.na(unlist(or)))) == TRUE) {
-        for (i in 1:length(or)) {
+        for (i in seq_len(length(or))) {
             ifelse(isTRUE(is.null(or[[i]])) == TRUE, or[[i]] <- NA, 
                 NA)
         }
@@ -45,12 +45,16 @@ function (x, clu, rev = FALSE)
             prm[nor[i]] <- i
         }
         rm(i)
-        ifelse(isTRUE(rev == TRUE) == TRUE, return(x[rev(prm), 
-            rev(prm)]), return(x[prm, prm]))
+        ifelse(isTRUE(rev == TRUE) == TRUE, px <- x[rev(prm), 
+            rev(prm)], px <- x[prm, prm])
+        ifelse(missing(lbs) == FALSE && isTRUE(length(lbs) == 
+            dim(x)[1]) == TRUE, dimnames(px)[[1]] <- dimnames(px)[[2]] <- lbs, 
+            NA)
+        return(px)
     }
     else {
         px <- x
-        for (k in 1:dim(px)[3]) {
+        for (k in seq_len(dim(px)[3])) {
             prm <- vector()
             for (i in nor) {
                 prm[nor[i]] <- i
@@ -59,13 +63,20 @@ function (x, clu, rev = FALSE)
             px[, , k] <- px[prm, prm, k]
         }
         rm(k)
-        if (isTRUE(is.null(dimnames(x)[[1]]) == FALSE)) {
-            lbs <- vector()
-            length(lbs) <- length(clu)
-            for (i in 1:length(nor)) lbs[i] <- dimnames(x)[[1]][which(nor == 
-                i)]
+        if (missing(lbs) == FALSE && isTRUE(length(lbs) == dim(x)[1]) == 
+            TRUE) {
             dimnames(px)[[1]] <- dimnames(px)[[2]] <- lbs
         }
+        else if (is.null(dimnames(x)[[1]]) == FALSE) {
+            Lbs <- vector()
+            length(Lbs) <- length(clu)
+            for (i in seq_len(length(nor))) Lbs[i] <- dimnames(x)[[1]][which(nor == 
+                i)]
+            dimnames(px)[[1]] <- dimnames(px)[[2]] <- Lbs
+        }
+        else {
+            NA
+        }
         ifelse(isTRUE(is.null(dimnames(x)[[3]]) == FALSE), dimnames(px)[[3]] <- dimnames(x)[[3]], 
             NA)
         return(px)
