@@ -1,5 +1,5 @@
 reduc <-
-function (x, clu, labels = NULL) 
+function (x, clu, lbs = NULL) 
 {
     if (isTRUE(is.array(x) == TRUE) == FALSE) 
         stop("'x' must be an array object.")
@@ -11,11 +11,11 @@ function (x, clu, labels = NULL)
     }
     else if (is.character(clu) == TRUE) {
         tmp <- clu
-        for (i in 1:nlevels(factor(clu))) {
+        for (i in seq_len(nlevels(factor(clu)))) {
             clu[which(levels(factor(tmp))[i] == clu)] <- i
         }
         rm(i)
-        clu <- methods::as(clu, "numeric")
+        clu <- as.numeric(clu)
         rm(tmp)
     }
     else {
@@ -32,7 +32,7 @@ function (x, clu, labels = NULL)
     cls <- list()
     length(cls) <- lngt
     k <- 1L
-    for (i in 1:length(or)) {
+    for (i in seq_len(length(or))) {
         if (isTRUE(is.null(or[[i]])) == FALSE) {
             cls[[k]] <- or[[i]]
             k <- k + 1L
@@ -44,25 +44,25 @@ function (x, clu, labels = NULL)
     rm(i, k)
     if (isTRUE(is.na(dim(x)[3]) == TRUE)) {
         if (isTRUE(is.null(dimnames(x)[[1]]) == TRUE) == TRUE) 
-            dimnames(x)[[1]] <- dimnames(x)[[2]] <- 1:nrow(x)
+            dimnames(x)[[1]] <- dimnames(x)[[2]] <- seq_len(nrow(x))
         bm <- array(dim = c(lngt, lngt))
-        for (i in 1:lngt) {
-            for (j in 1:lngt) {
+        for (i in seq_len(lngt)) {
+            for (j in seq_len(lngt)) {
                 bm[i, j] <- sum(x[cls[[i]], cls[[j]]])
             }
         }
         rm(i, j)
         bm <- dichot(bm)
-        ifelse(is.null(labels) == FALSE, rownames(bm) <- colnames(bm) <- labels, 
+        ifelse(is.null(lbs) == FALSE, rownames(bm) <- colnames(bm) <- lbs, 
             NA)
         return(bm)
     }
     else if (isTRUE(is.na(dim(x)[3]) == FALSE)) {
         px <- x
         bm <- array(dim = c(lngt, lngt, dim(x)[3]))
-        for (k in 1:dim(x)[3]) {
-            for (i in 1:lngt) {
-                for (j in 1:lngt) {
+        for (k in seq_len(dim(x)[3])) {
+            for (i in seq_len(lngt)) {
+                for (j in seq_len(lngt)) {
                   bm[i, j, k] <- sum(px[cls[[i]], cls[[j]], k])
                 }
             }
@@ -70,8 +70,8 @@ function (x, clu, labels = NULL)
         }
         rm(k)
         bm <- dichot(bm, c = 1L)
-        if (is.null(labels) == FALSE) 
-            dimnames(bm)[[1]] <- dimnames(bm)[[2]] <- labels
+        if (is.null(lbs) == FALSE) 
+            dimnames(bm)[[1]] <- dimnames(bm)[[2]] <- lbs
         if (is.null(dimnames(x)[[3]]) == FALSE) 
             dimnames(bm)[[3]] <- dimnames(x)[[3]]
         return(bm)
