@@ -1,9 +1,9 @@
 reducs <-
-function (x, clu, labels = NULL) 
+function (x, clu) 
 {
     lngt <- nlevels(factor(clu))
     cls <- list()
-    for (i in 1:lngt) {
+    for (i in seq_len(lngt)) {
         cls[[i]] <- which(clu == i)
     }
     rm(i)
@@ -20,50 +20,45 @@ function (x, clu, labels = NULL)
     tab <- tabulate(clu)
     bm <- array(dim = c(lngt, lngt))
     y <- h <- j <- 0
-    for (i in 1:lngt) {
-        k <- ((y + 1):(y + tabulate(clu)[i]))
-        for (j in 1:lngt) {
-            for (q in 1:length(cls)) {
+    for (i in seq_len(lngt)) {
+        k <- ((y + 1L):(y + tabulate(clu)[i]))
+        for (j in seq_len(lngt)) {
+            for (q in seq_len(length(cls))) {
                 if (all(unique(as.numeric(levels(factor(as.matrix(x[which(clu == 
                   i), which(clu == j)]))))) %in% cls[[q]]) == 
                   TRUE) {
                   if (isTRUE(attr(tmp, "class")[2] == "symbolic") == 
                     TRUE) {
                     bm[i, j] <- lb[min(as.numeric(as.matrix(px[k, 
-                      (h + 1):(h + tabulate(clu)[j])])))]
+                      (h + 1L):(h + tabulate(clu)[j])])))]
                   }
                   else if (isTRUE(attr(tmp, "class")[2] == "numerical") == 
                     TRUE) {
                     bm[i, j] <- min(as.numeric(as.matrix(px[k, 
-                      (h + 1):(h + tabulate(clu)[j])])))
+                      (h + 1L):(h + tabulate(clu)[j])])))
                   }
                 }
             }
             if (isTRUE(j > 0) == TRUE) 
-                h <- sum(tab[1:j])
+                h <- sum(tab[seq_len(j)])
         }
         rm(j)
         h <- 0
-        y <- sum(tab[1:i])
+        y <- sum(tab[seq_len(i)])
     }
     rm(i)
-    if (is.null(labels) == FALSE) {
-        lbs <- labels
-    }
-    else if (is.null(labels) == TRUE) {
-        lbs <- vector()
-        for (i in 1:length(tabulate(clu))) {
-            ifelse(isTRUE(attr(tmp, "class")[2] == "symbolic") == 
-                TRUE, lbs[length(lbs) + 1] <- lb[which(clu == 
-                i)[1]], lbs[length(lbs) + 1] <- as.numeric(dimnames(x)[[1]])[which(clu == 
+    lbs <- vector()
+    for (i in seq_len(length(tabulate(clu)))) {
+        ifelse(isTRUE(attr(tmp, "class")[2] == "symbolic") == 
+            TRUE, lbs[length(lbs) + 1L] <- lb[which(clu == i)[1]], 
+            lbs[length(lbs) + 1L] <- as.numeric(dimnames(x)[[1]])[which(clu == 
                 i)[1]])
-        }
-        rm(i)
     }
-    for (i in 1:dim(bm)[1]) {
-        for (j in 1:dim(bm)[1]) {
+    rm(i)
+    for (i in seq_len(dim(bm)[1])) {
+        for (j in seq_len(dim(bm)[1])) {
             if (isTRUE(bm[i, j] %in% lbs) == FALSE) {
-                for (l in 1:length(lbs)) {
+                for (l in seq_len(length(lbs))) {
                   if (isTRUE(attr(tmp, "class")[2] == "symbolic") == 
                     TRUE) {
                     if (isTRUE(bm[i, j] %in% lbs[l]) == TRUE) 
